package	jp.co.sds_corp.ftp;

import java.util.StringTokenizer;

public class FtpFile
{
	public enum Type {
		FIFO,
		CHAR,
		DIR,
		BLOCK,
		REG,
		LINK,
		SOCK,
		DOOR,
		UNKNOWN
	}
	Type type = Type.UNKNOWN;
	String	perm;
	String	owner;
	String	group;
	long	lSize;
	String	date;
	String	name;

	/**
	* コンストラクタ
	*/
	public FtpFile() {
	}

	/**
	* コンストラクタ
	* @param	line		FTP Serverから取得したファイル情報
	*/
	public FtpFile( String line ) {
		parseLine( line );
	}

	/**
	* FTP Serverから取得したファイル情報を解析し、データを格納します
	* @param	line		FTP Serverから取得したファイル情報
	*/
	public void parseLine( String line ) {
		StringTokenizer tok = new StringTokenizer( line, " \t" );
		int		nNum = tok.countTokens();
		if ( nNum < 0 ) {
			throw( new IllegalArgumentException( "token not found" ));
		}
		String[] buf = new String[ nNum ];
		int  i = 0;
		while ( tok.hasMoreTokens()) {
			buf[i] = tok.nextToken();
			i++;
		}

		switch ( buf[0].charAt( 0 )) {
		case 'd' : setType( Type.DIR ); break;
		case 'D' : setType( Type.DOOR ); break;
		case 'l' : setType( Type.LINK ); break;
		case 'b' : setType( Type.BLOCK ); break;
		case 'c' : setType( Type.CHAR ); break;
		case 'p' : setType( Type.FIFO ); break;
		case 's' : setType( Type.SOCK ); break;
		case '-' : setType( Type.REG ); break;
		}
		setPermission( buf[0].substring( 1 ));
		setOwner( buf[2] );
		setGroup( buf[3] );
		long lSize = -1;
		try {
			lSize = Long.valueOf( buf[4] ).longValue();
		} catch ( Exception e ) {
		}
		if ( lSize >= 0 ) {
			setSize( lSize );
		}
		setName( buf[nNum-1] );
	}

	/**
	* ファイルの種別をcharで返します
	* @return	ファイル種別
	*/
	public char getTypeChar() {
		char	cRet;
		switch ( type ) {
		case FIFO	: cRet = 'p'; break;
		case CHAR	: cRet = 'c'; break;
		case DIR	: cRet = 'd'; break;
		case BLOCK	: cRet = 'b'; break;
		case REG	: cRet = '-'; break;
		case LINK	: cRet = 'l'; break;
		case SOCK	: cRet = 's'; break;
		case DOOR	: cRet = 'D'; break;
		default: cRet = '?'; break;
		}
		return cRet;
	}

	/**
	* ファイルの名前を設定します
	* @param	var		名前
	*/
	public void setName( String var ) {
		name = var;
	}
	/**
	* ファイルの名前を取得します
	* @return	名前
	*/
	public String getName() {
		return name;
	}

	/**
	* ファイルのアクセス権を設定します
	* @param	var		アクセス権
	*/
	public void setPermission( String var ) {
		perm = var;
	}
	/**
	* ファイルのアクセス権を取得します
	* @return	アクセス権
	*/
	public String getPermission() {
		return perm;
	}

	/**
	* ファイルの所有者を設定します
	* @param	var		所有者
	*/
	public void setOwner( String var ) {
		owner = var;
	}
	/**
	* ファイルの所有者を取得します
	* @return	所有者
	*/
	public String getOwner() {
		return owner;
	}

	/**
	* ファイルのグループを設定します
	* @param	var		グループ
	*/
	public void setGroup( String var ) {
		group = var;
	}
	/**
	* ファイルのグループを取得します
	* @return	グループ
	*/
	public String getGroup() {
		return group;
	}

	/**
	* ファイルの日付を設定します
	* @param	var		日付
	*/
	public void setDate( String var ) {
		date = var;
	}
	/**
	* ファイルの日付を取得します
	* @return	日付
	*/
	public String getDate() {
		return date;
	}

	/**
	* ファイルのサイズを設定します
	* @param	var		サイズ
	*/
	public void setSize( long var ) {
		lSize = var;
	}
	/**
	* ファイルのサイズを取得します
	* @return	サイズ
	*/
	public long getSize() {
		return lSize;
	}

	/**
	* ファイルのタイプを設定します
	* @param	var		タイプ
	*/
	public void setType( Type var ) {
		type = var;
	}
	/**
	* ファイルのタイプを取得します
	* @return	タイプ
	*/
	public Type getType() {
		return type;
	}

	/**
	* このファイルの文字列表現を返します。
	*/
	public String toString() {
		String ret = name;
		return ret;
	}

}
